@@ -212,7 +212,7 @@ class Position(RedBirdObject):
     账号持仓
     """
     def __init__(self, symbol=None, price=None, quantity=None, closeableQuantity=None, lockedQuantity=None, costPrice=None,
-                 marketValue=None, pnl=None, pnlPercentage=None):
+                 marketValue=None, pnl=None, pnlPercentage=None, holdingDays=None):
         """
         账号持仓对象初始化
         :param symbol:股票代码
@@ -224,6 +224,7 @@ class Position(RedBirdObject):
         :param marketValue:市值
         :param pnl:损益
         :param pnlPercentage:损益百分比
+        :param holdingDays:持股天数
         """
         self.symbol = symbol
         self.price = price
@@ -234,6 +235,7 @@ class Position(RedBirdObject):
         self.marketValue = marketValue
         self.pnl = pnl
         self.pnlPercentage = pnlPercentage
+        self.holdingDays = holdingDays
 
 
 class Positions(RedBirdObject):
